commonapi

package
v1.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 29, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Overview

Package commonapi provides shared request handling logic used by both the Client API and Primary domain layer, such as Range queries.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Range

Range executes the shared Range request logic against the local database.

Types

This section is empty.

Jump to