Documentation
¶
Overview ¶
Package datafile provides a public API for external tools that need to read and write Netsy .netsy data files.
This package intentionally exposes plain Go types instead of generated protobuf types. Netsy internals should continue to use internal/datafile
Record byte slices are not defensively copied. Callers must not mutate them concurrently with read or write operations.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WriteChunk ¶
WriteChunk writes records as a Netsy chunk file.
Types ¶
type Record ¶
type Record struct {
Revision int64
Key []byte
Created bool
Deleted bool
CreateRevision int64
PrevRevision int64
Version int64
Lease int64
Dek int64
Value []byte
CreatedAt *time.Time
CompactedAt *time.Time
LeaderID string
ReplicatedAt *time.Time
}
Record is a Netsy key-value record stored in a .netsy data file.
Click to show internal directories.
Click to hide internal directories.